==> zio-aws-iot_2.12-5.17.191.2-sources.jar: zio/aws/iot/model/FleetMetricNameAndArn.scala <==
package zio.aws.iot.model
import zio.ZIO
import zio.aws.iot.model.primitives.{FleetMetricArn, FleetMetricName}
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class FleetMetricNameAndArn(
    metricName: Optional[FleetMetricName] = Optional.Absent,
    metricArn: Optional[FleetMetricArn] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iot.model.FleetMetricNameAndArn = {
    import FleetMetricNameAndArn.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iot.model.FleetMetricNameAndArn
      .builder()
      .optionallyWith(
        metricName.map(value => FleetMetricName.unwrap(value): java.lang.String)
      )(_.metricName)
      .optionallyWith(
        metricArn.map(value => FleetMetricArn.unwrap(value): java.lang.String)
      )(_.metricArn)
      .build()
  }
  def asReadOnly: zio.aws.iot.model.FleetMetricNameAndArn.ReadOnly =
    zio.aws.iot.model.FleetMetricNameAndArn.wrap(buildAwsValue())
}
object FleetMetricNameAndArn {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iot.model.FleetMetricNameAndArn
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iot.model.FleetMetricNameAndArn =
      zio.aws.iot.model.FleetMetricNameAndArn(
        metricName.map(value => value),
        metricArn.map(value => value)
      )
    def metricName: Optional[FleetMetricName]
    def metricArn: Optional[FleetMetricArn]
    def getMetricName: ZIO[Any, AwsError, FleetMetricName] =
      AwsError.unwrapOptionField("metricName", metricName)
    def getMetricArn: ZIO[Any, AwsError, FleetMetricArn] =
      AwsError.unwrapOptionField("metricArn", metricArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iot.model.FleetMetricNameAndArn
  ) extends zio.aws.iot.model.FleetMetricNameAndArn.ReadOnly {
    override val metricName: Optional[FleetMetricName] = zio.aws.core.internal
      .optionalFromNullable(impl.metricName())
      .map(value => zio.aws.iot.model.primitives.FleetMetricName(value))
    override val metricArn: Optional[FleetMetricArn] = zio.aws.core.internal
      .optionalFromNullable(impl.metricArn())
      .map(value => zio.aws.iot.model.primitives.FleetMetricArn(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.iot.model.FleetMetricNameAndArn
  ): zio.aws.iot.model.FleetMetricNameAndArn.ReadOnly = new Wrapper(impl)
}

==> zio-aws-iot_3-5.17.104.11-sources.jar: zio/aws/iot/model/FleetMetricNameAndArn.scala <==
package zio.aws.iot.model
import zio.ZIO
import zio.aws.iot.model.primitives.{FleetMetricArn, FleetMetricName}
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class FleetMetricNameAndArn(
    metricName: Option[FleetMetricName] = None,
    metricArn: Option[FleetMetricArn] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iot.model.FleetMetricNameAndArn = {
    import FleetMetricNameAndArn.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iot.model.FleetMetricNameAndArn
      .builder()
      .optionallyWith(
        metricName.map(value => FleetMetricName.unwrap(value): java.lang.String)
      )(_.metricName)
      .optionallyWith(
        metricArn.map(value => FleetMetricArn.unwrap(value): java.lang.String)
      )(_.metricArn)
      .build()
  }
  def asReadOnly: zio.aws.iot.model.FleetMetricNameAndArn.ReadOnly =
    zio.aws.iot.model.FleetMetricNameAndArn.wrap(buildAwsValue())
}
object FleetMetricNameAndArn {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iot.model.FleetMetricNameAndArn
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iot.model.FleetMetricNameAndArn =
      zio.aws.iot.model.FleetMetricNameAndArn(
        metricName.map(value => value),
        metricArn.map(value => value)
      )
    def metricName: Option[FleetMetricName]
    def metricArn: Option[FleetMetricArn]
    def getMetricName: ZIO[Any, AwsError, FleetMetricName] =
      AwsError.unwrapOptionField("metricName", metricName)
    def getMetricArn: ZIO[Any, AwsError, FleetMetricArn] =
      AwsError.unwrapOptionField("metricArn", metricArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iot.model.FleetMetricNameAndArn
  ) extends zio.aws.iot.model.FleetMetricNameAndArn.ReadOnly {
    override val metricName: Option[FleetMetricName] = scala
      .Option(impl.metricName())
      .map(value => zio.aws.iot.model.primitives.FleetMetricName(value))
    override val metricArn: Option[FleetMetricArn] = scala
      .Option(impl.metricArn())
      .map(value => zio.aws.iot.model.primitives.FleetMetricArn(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.iot.model.FleetMetricNameAndArn
  ): zio.aws.iot.model.FleetMetricNameAndArn.ReadOnly = new Wrapper(impl)
}
